summaryrefslogtreecommitdiffstats
path: root/kpdf/ui/propertiesdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpdf/ui/propertiesdialog.cpp')
-rw-r--r--kpdf/ui/propertiesdialog.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kpdf/ui/propertiesdialog.cpp b/kpdf/ui/propertiesdialog.cpp
index d3d0af60..d9cee932 100644
--- a/kpdf/ui/propertiesdialog.cpp
+++ b/kpdf/ui/propertiesdialog.cpp
@@ -8,7 +8,7 @@
***************************************************************************/
// qt/kde includes
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <klistview.h>
#include <klocale.h>
@@ -24,18 +24,18 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
{
// Properties
TQFrame *page = addPage(i18n("Properties"));
- TQGridLayout *layout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
+ TQGridLayout *tqlayout = new TQGridLayout( page, 2, 2, marginHint(), spacingHint() );
// get document info, if not present display blank data and a warning
const DocumentInfo * info = doc->documentInfo();
if ( !info ) {
- layout->addWidget( new TQLabel( i18n( "No document opened." ), page ), 0, 0 );
+ tqlayout->addWidget( new TQLabel( i18n( "No document opened." ), page ), 0, 0 );
return;
}
// mime name based on mimetype id
TQString mimeName = info->get( "mimeType" ).section( '/', -1 ).upper();
- setCaption( i18n("%1 Properties").arg( mimeName ) );
+ setCaption( i18n("%1 Properties").tqarg( mimeName ) );
TQDomElement docElement = info->documentElement();
@@ -49,11 +49,11 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
if ( titleString.isEmpty() || valueString.isEmpty() )
continue;
- // create labels and layout them
- TQLabel *key = new TQLabel( i18n( "%1:" ).arg( titleString ), page );
+ // create labels and tqlayout them
+ TQLabel *key = new TQLabel( i18n( "%1:" ).tqarg( titleString ), page );
TQLabel *value = new KSqueezedTextLabel( valueString, page );
- layout->addWidget( key, row, 0, AlignRight );
- layout->addWidget( value, row, 1 );
+ tqlayout->addWidget( key, row, 0, AlignRight );
+ tqlayout->addWidget( value, row, 1 );
row++;
// refine maximum width of 'value' labels
@@ -66,8 +66,8 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
TQLabel *key = new TQLabel( i18n( "Pages:" ), page );
TQLabel *value = new TQLabel( TQString::number( doc->pages() ), page );
- layout->addWidget( key, row, 0 );
- layout->addWidget( value, row, 1 );
+ tqlayout->addWidget( key, row, 0 );
+ tqlayout->addWidget( value, row, 1 );
}
// Fonts
@@ -82,10 +82,10 @@ PropertiesDialog::PropertiesDialog(TQWidget *parent, KPDFDocument *doc)
}
// current width: left column + right column + dialog borders
- int width = layout->minimumSize().width() + valMaxWidth + marginHint() + spacingHint() + marginHint() + 30;
+ int width = tqlayout->tqminimumSize().width() + valMaxWidth + marginHint() + spacingHint() + marginHint() + 30;
if (page2Layout)
{
- width = TQMAX( width, page2Layout->sizeHint().width() + marginHint() + spacingHint() + 31 );
+ width = TQMAX( width, page2Layout->tqsizeHint().width() + marginHint() + spacingHint() + 31 );
}
// stay inside the 2/3 of the screen width
TQRect screenContainer = KGlobalSettings::desktopGeometry( this );